barrel_p2p_quic_cert (barrel_p2p v0.1.0)

Summary

Functions

Ensure QUIC certificates exist, generating them if needed. Uses default directory from application config.

Ensure QUIC certificates exist in the specified directory.

Generate a new self-signed certificate and key.

Get the paths to the certificate and key files.

Functions

ensure_cert()

-spec ensure_cert() -> ok | {error, term()}.

Ensure QUIC certificates exist, generating them if needed. Uses default directory from application config.

ensure_cert(CertDir)

-spec ensure_cert(file:filename()) -> ok | {error, term()}.

Ensure QUIC certificates exist in the specified directory.

generate_cert(CertDir)

-spec generate_cert(file:filename()) -> ok | {error, term()}.

Generate a new self-signed certificate and key.

get_cert_paths()

-spec get_cert_paths() -> {CertFile :: file:filename(), KeyFile :: file:filename()}.

Get the paths to the certificate and key files.